import * as React from 'react';

type ExportImageType = "jpeg" | "png";
interface ExportImageOptions {
    readonly width?: number;
    readonly height?: number;
}
interface Point {
    readonly x: number;
    readonly y: number;
}
interface CanvasPath {
    readonly paths: Point[];
    readonly strokeWidth: number;
    readonly strokeColor: string;
    readonly drawMode: boolean;
    readonly startTimestamp?: number;
    readonly endTimestamp?: number;
}

interface CanvasProps {
    paths: CanvasPath[];
    isDrawing: boolean;
    onPointerDown: (point: Point, isEraser?: boolean) => void;
    onPointerMove: (point: Point) => void;
    onPointerUp: () => void;
    allowOnlyPointerType: string;
    backgroundImage: string;
    canvasColor: string;
    className?: string;
    exportWithBackgroundImage: boolean;
    height: string;
    id?: string;
    preserveBackgroundImageAspectRatio: string;
    style: React.CSSProperties;
    svgStyle: React.CSSProperties;
    withViewBox?: boolean;
    width: string;
    readOnly?: boolean;
}
interface CanvasRef {
    exportImage: (imageType: ExportImageType, options?: ExportImageOptions) => Promise<string>;
    exportSvg: () => Promise<string>;
}
declare const Canvas: React.ForwardRefExoticComponent<CanvasProps & React.RefAttributes<CanvasRef>>;

interface ReactSketchCanvasProps extends Partial<Omit<CanvasProps, "paths" | "isDrawing" | "onPointerDown" | "onPointerMove" | "onPointerUp">> {
    eraserWidth?: number;
    onChange?: (updatedPaths: CanvasPath[]) => void;
    onStroke?: (path: CanvasPath, isEraser: boolean) => void;
    strokeColor?: string;
    strokeWidth?: number;
    withTimestamp?: boolean;
}
interface ReactSketchCanvasRef {
    eraseMode: (_erase: boolean) => void;
    clearCanvas: () => void;
    undo: () => void;
    redo: () => void;
    exportImage: (imageType: ExportImageType) => Promise<string>;
    exportSvg: () => Promise<string>;
    exportPaths: () => Promise<CanvasPath[]>;
    loadPaths: (paths: CanvasPath[]) => void;
    getSketchingTime: () => Promise<number>;
    resetCanvas: () => void;
}
declare const ReactSketchCanvas: React.ForwardRefExoticComponent<ReactSketchCanvasProps & React.RefAttributes<ReactSketchCanvasRef>>;

export { Canvas, type CanvasPath, type CanvasProps, type CanvasRef, type ExportImageOptions, type ExportImageType, type Point, ReactSketchCanvas, type ReactSketchCanvasProps, type ReactSketchCanvasRef };
